==================
``sorting`` module
==================

.. automodule:: whoosh.sorting


Base types
==========

.. autoclass:: FacetType
    :members:

.. autoclass:: Categorizer
    :members:


Facet types
===========

.. autoclass:: FieldFacet
.. autoclass:: QueryFacet
.. autoclass:: RangeFacet
.. autoclass:: DateRangeFacet
.. autoclass:: ScoreFacet
.. autoclass:: FunctionFacet
.. autoclass:: MultiFacet
.. autoclass:: StoredFieldFacet


Facets object
=============

.. autoclass:: Facets
    :members:


FacetType objects
=================

.. autoclass:: FacetMap
    :members:
.. autoclass:: OrderedList
.. autoclass:: UnorderedList
.. autoclass:: Count
.. autoclass:: Best


